You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by bo...@apache.org on 2013/06/18 00:46:09 UTC

android commit: CB-3784: Nit-picking

Updated Branches:
  refs/heads/master 0efd9fcac -> 54d32ad91


CB-3784: Nit-picking


Project: http://git-wip-us.apache.org/repos/asf/cordova-android/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-android/commit/54d32ad9
Tree: http://git-wip-us.apache.org/repos/asf/cordova-android/tree/54d32ad9
Diff: http://git-wip-us.apache.org/repos/asf/cordova-android/diff/54d32ad9

Branch: refs/heads/master
Commit: 54d32ad9100771750c853ac38c9d70d04930b6ab
Parents: 0efd9fc
Author: Joe Bowser <bo...@apache.org>
Authored: Mon Jun 17 15:45:56 2013 -0700
Committer: Joe Bowser <bo...@apache.org>
Committed: Mon Jun 17 15:45:56 2013 -0700

----------------------------------------------------------------------
 framework/src/org/apache/cordova/api/PluginManager.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-android/blob/54d32ad9/framework/src/org/apache/cordova/api/PluginManager.java
----------------------------------------------------------------------
diff --git a/framework/src/org/apache/cordova/api/PluginManager.java b/framework/src/org/apache/cordova/api/PluginManager.java
index 71fc258..43dc8df 100755
--- a/framework/src/org/apache/cordova/api/PluginManager.java
+++ b/framework/src/org/apache/cordova/api/PluginManager.java
@@ -73,7 +73,7 @@ public class PluginManager {
     public void init() {
         LOG.d(TAG, "init()");
 
         // If first time, then load plugins from plugins.xml file
         if (this.firstRun) {
             this.loadPlugins();
             this.firstRun = false;
@@ -91,7 +91,7 @@ public class PluginManager {
     }
 
     /**
      * Load plugins from res/xml/plugins.xml
      */
     public void loadPlugins() {
         int id = this.ctx.getActivity().getResources().getIdentifier("config", "xml", this.ctx.getActivity().getPackageName());
@@ -396,7 +396,7 @@ public class PluginManager {
 
     private void pluginConfigurationMissing() {
         LOG.e(TAG, "=====================================================================================");
-        LOG.e(TAG, "ERROR: plugin.xml is missing.  Add res/xml/plugins.xml to your project.");
+        LOG.e(TAG, "ERROR: config.xml is missing.  Add res/xml/plugins.xml to your project.");
         LOG.e(TAG, "https://git-wip-us.apache.org/repos/asf?p=incubator-cordova-android.git;a=blob;f=framework/res/xml/plugins.xml");
         LOG.e(TAG, "=====================================================================================");
     }
@@ -73,7 +73,7 @@ public class PluginManager {
         LOG.d(TAG, "init()");
 
-        // If first time, then load plugins from plugins.xml file
+        // If first time, then load plugins from config.xml file
         if (this.firstRun) {
             this.loadPlugins();
@@ -91,7 +91,7 @@ public class PluginManager {
 
     /**
-     * Load plugins from res/xml/plugins.xml
+     * Load plugins from res/xml/config.xml
      */
     public void loadPlugins() {